pub struct RigClientCompletionModelAdapter { /* private fields */ }Trait Implementations
Sourceimpl Clone for RigClientCompletionModelAdapter
impl Clone for RigClientCompletionModelAdapter
Sourcefn clone(&self) -> RigClientCompletionModelAdapter
fn clone(&self) -> RigClientCompletionModelAdapter
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompletionModel for RigClientCompletionModelAdapter
impl CompletionModel for RigClientCompletionModelAdapter
Sourcetype StreamingResponse = FinalCompletionResponse
type StreamingResponse = FinalCompletionResponse
The raw response type returned by the underlying completion model when streaming.
type Client = Client
fn make(client: &Self::Client, model: impl Into<String>) -> Self
Sourcefn completion(
&self,
request: CompletionRequest,
) -> impl Future<Output = Result<CompletionResponse<Self::Response>, CompletionError>> + WasmCompatSend
fn completion( &self, request: CompletionRequest, ) -> impl Future<Output = Result<CompletionResponse<Self::Response>, CompletionError>> + WasmCompatSend
Generates a completion response for the given completion request.
fn stream( &self, _request: CompletionRequest, ) -> impl Future<Output = Result<StreamingCompletionResponse<Self::StreamingResponse>, CompletionError>> + WasmCompatSend
Sourcefn completion_request(
&self,
prompt: impl Into<Message>,
) -> CompletionRequestBuilder<Self>
fn completion_request( &self, prompt: impl Into<Message>, ) -> CompletionRequestBuilder<Self>
Generates a completion request builder for the given
prompt.Auto Trait Implementations
impl Freeze for RigClientCompletionModelAdapter
impl !RefUnwindSafe for RigClientCompletionModelAdapter
impl Send for RigClientCompletionModelAdapter
impl Sync for RigClientCompletionModelAdapter
impl Unpin for RigClientCompletionModelAdapter
impl UnsafeUnpin for RigClientCompletionModelAdapter
impl !UnwindSafe for RigClientCompletionModelAdapter