Client

Enum Client 

pub enum Client {
Show 17 variants Anthropic(Client), Azure(Client), Cohere(Client), DeepSeek(Client), Galadriel(Client), Gemini(Client), Groq(Client), HuggingFace(Client), Hyperbolic(Client), Mira(Client), Moonshot(Client), OpenAI(Client), OpenRouter(Client), Ollama(Client), Perplexity(Client), Together(Client), Xai(Client),
}

Variants



Anthropic(Client)



Azure(Client)



Cohere(Client)



DeepSeek(Client)



Galadriel(Client)



Gemini(Client)



Groq(Client)



HuggingFace(Client)



Hyperbolic(Client)



Mira(Client)



Moonshot(Client)



OpenAI(Client)



OpenRouter(Client)



Ollama(Client)



Perplexity(Client)



Together(Client)



Xai(Client)

Implementations

Source

impl Client

pub async fn completion_model(&self, model: &str) -> Box<dyn CompletionModel>

Returns a completion model wrapper for the given provider and model name.

pub async fn embedding_model( &self, model: &str, input_type: Option<&str>, ) -> Option<Box<dyn EmbeddingModel>>

Returns an embedding model wrapper for the given provider and model name. Returns None if the provider does not support embeddings or if improper input type is provided (cohere requires a input type).

pub async fn embedding_model_with_ndims( &self, model: &str, ndims: usize, input_type: Option<&str>, ) -> Option<Box<dyn EmbeddingModel>>